;Filename: TWkk.s
;Part: ADuC703x.
;Created: 12/04/2006
;Author: Eckart Hartmann of Analog Devices
;This file is in beta sampling.

;This software is supplied subject our standard software license agreement.
;A non-binding summary is as follows:
;"You may use the software in your own code at your own risk.
;" ADI inc disclaims any warranty or liability of its use".
;The full standard software license agreement is available on request and
; remains the binding agreement.

#include        "..\Fla\ADuC703xi.equ"

; TWd==========Sets the watchdog mode switches of T3CON.
; C Function prototype: int TWd(int iT, int iEnable, int iPdOff, int iWdIrq);
;iT:{T_T3,}
;iEnable:{T_Disable,T_Enable}
;iPdOff:{T_OnInPd,T_OffInPd}
;iWdIrq:{T_WdRst,T_WdIrq}
; Description of Function: Configures watchdog mode switches.
; User interface:
;   Set iT to 3.
;   Set iEnable to 1 to enable watchdog mode.
;   Set iPdOff to 1 to stop watchdog during powerdown.
;   Set iWdIrq to 1 to produce an IRQ instead of reset when watchdog expires.
;   Call TWd(iT, iEnable, iPdOff, iWdIrq).
;       Timer 3 is stopped and the specified modes set.
;   Returns in r0 the value written to T3CON.
; Robustness:
;  Configure the timer with TCfg() TMod() and TVal() before using TWd().
;  Once enabled the watchdog can not be disabled - see data sheet.
;  Only works with T3. Will have no effect if used on other timers.
; Side effects: Corrupts r1 to r3.

                RSEG CODE
                MODULE TWd
                PUBLIC TWd
                CODE32

TWd:    cmp     r0,#3                   ;if(iT!=3)
        bne     TWdR                    ; exit.

        and     r2,r2,#1                ;Get PD_OFF bit.
        and     r1,r1,#1                ;Add enable bit.
        orr     r2,r2,r1,LSL#5
        and     r3,r3,#1                ;Add WD_IRQ bit.
        orr     r2,r2,r3,LSL#1

        mov     r3,#0xff0000            ;r3 = Z_BASE;
        orr     r3,r3,#0xff000000

        ldr     r0,[r3,#Z_T3CON]        ;Get current settings.
        bic     r0,r0,#0x23             ;Remove watchdog bits.
        orr     r0,r0,r2                ;Add new bits
        str     r0,[r3,#Z_T3CON]        ; to T3CON.
TWdR:   bx      lr

                 ENDMOD  TWd
                 END

